EpochConsensus

Struct EpochConsensus 

pub struct EpochConsensus<V: Clone> { /* private fields */ }
Abortable consensus within one epoch.

Implementations

Source

impl<V: Clone> EpochConsensus<V>

pub fn new( me: NodeId, peers: impl IntoIterator<Item = NodeId>, ets: u64, leader: NodeId, state: State<V>, retransmit: Duration, ) -> Self

⟨ ep, Init | state ⟩ — an instance for epoch ets led by leader, beginning from state.

pub fn timestamp(&self) -> u64

This epoch’s timestamp.

pub fn is_aborted(&self) -> bool

Whether this instance has been abandoned and is therefore silent.

pub fn state(&self) -> &State<V>

What this process has accepted, and when.