pub struct EpochConsensus<V: Clone> { /* private fields */ }Expand description
Abortable consensus within one epoch.
Implementations
Sourceimpl<V: Clone> EpochConsensus<V>
impl<V: Clone> EpochConsensus<V>
Sourcepub fn new(
me: NodeId,
peers: impl IntoIterator<Item = NodeId>,
ets: u64,
leader: NodeId,
state: State<V>,
retransmit: Duration,
) -> Self
pub fn new( me: NodeId, peers: impl IntoIterator<Item = NodeId>, ets: u64, leader: NodeId, state: State<V>, retransmit: Duration, ) -> Self
⟨ ep, Init | state ⟩ — an instance for epoch ets led by leader, beginning from state.
Sourcepub fn is_aborted(&self) -> bool
pub fn is_aborted(&self) -> bool
Whether this instance has been abandoned and is therefore silent.